@@ -1,10 +1,7 @@
-/* eslint-disable
-  prefer-destructuring,
-*/
-import webpack from '@webpack-contrib/test-utils';
+import webpack from './helpers/compiler';
 
 describe('mimetype option', () => {
-  test('{undefined}', async () => {
+  it('{undefined}', async () => {
     const config = {
       loader: {
         test: /\.png$/,
@@ -13,12 +10,12 @@ describe('mimetype option', () => {
     };
 
     const stats = await webpack('fixture.js', config);
-    const { source } = stats.toJson().modules[0];
+    const [{ source }] = stats.toJson().modules;
 
     expect(source).toMatchSnapshot();
   });
 
-  test('{String}', async () => {
+  it('{String}', async () => {
     const config = {
       loader: {
         test: /\.png$/,
@@ -29,7 +26,23 @@ describe('mimetype option', () => {
     };
 
     const stats = await webpack('fixture.js', config);
-    const { source } = stats.toJson().modules[0];
+    const [{ source }] = stats.toJson().modules;
+
+    expect(source).toMatchSnapshot();
+  });
+
+  it('unknown ({String})', async () => {
+    const config = {
+      loader: {
+        test: /\.png$/,
+        options: {
+          mimetype: 'unknown/unknown',
+        },
+      },
+    };
+
+    const stats = await webpack('fixture.js', config);
+    const [{ source }] = stats.toJson().modules;
 
     expect(source).toMatchSnapshot();
   });
